@@ -25,6 +25,7 @@ class Client():
             self.client.connect((self.ip, self.port))
             if self.console_output: outstr("INFO", f"Connected to {self.ip}:{self.port}")
             return 200, None
+            
         except Exception as e:
             return 500, e
 
@@ -51,9 +52,6 @@ class Client():
         if self.console_output: outstr("INFO", f"Disconnected from {self.ip}:{self.port}")
 
     def send(self, msg, method:SEND_METHOD=SEND_METHOD.default_send):
-        self.check_connection()
-
-        time.sleep(0.2)
         def _send(msg, method):
             if isinstance(msg, str):
                 msg = msg.encode()
@@ -79,16 +77,17 @@ class Client():
             _send(msg, method)
             return 200, None
         except ConnectionResetError as e:
+            self.check_connection()
             return 500, e
         except socket.timeout as e:
+            self.check_connection()
             return 500, e
-        except Exception:
-            raise Exception
+        except Exception as e:
+            self.check_connection()
+            raise e
     
     def recv(self, buffer:int=2048):
-        self.check_connection()
-
-        def _recv():
+        def _recv(buffer):
             received = self.client.recv(buffer).decode()
             if str(received) == "exit":
                 self.client.close()
@@ -126,13 +125,19 @@ class Client():
             return str(outp)
 
         try:
-            return {"code": 200, "response": _recv(buffer), "error": None},
+            return response_class(200, _recv(buffer), None)
+            
         except ConnectionResetError as e:
-            return {"code": 500, "response": None, "error": e},
+            self.check_connection()
+            return response_class(500, None, e)
+
         except socket.timeout as e:
-            return {"code": 500, "response": None, "error": e},
-        except Exception:
-            raise Exception
+            self.check_connection()
+            return response_class(500, None, e)
+
+        except Exception as e:
+            self.check_connection()
+            raise e
 
     @property
     def is_connected(self):
@@ -169,21 +174,24 @@ class Client():
 
     def _check_connection(self):
         try:
+            self.client.setblocking(0)
             self.client.settimeout(1.4)
             data = self.client.recv(16, socket.MSG_PEEK)
 
             if len(data) == 0:
                 return False
-            return True
-        except BlockingIOError:
 
+            self.client.setblocking(1)
+            return True
+
+        except BlockingIOError:
             return True 
+
         except ConnectionResetError:
 
             return False
             
         except socket.timeout:
-
             return True
         
         except WindowsError:
